#!/usr/bin/env bash
# -*- coding: utf-8 -*-

# Based on the Chromium Docker build by Ivan Aksamentov Ivan Aksamentov <ivan.aksamentov@gmail.com>
# https://github.com/ivan-aksamentov/docker-chromium
# Heavily inspired by this Dockerfile
# https://github.com/jessfraz/dockerfiles/tree/d871637d411bea624941c8732fe449c9d8a4b56e/chromium/Dockerfile
# by Jessie Frazelle @jessfraz https://twitter.com/jessfraz. 

# Runs `java:microcraft10` docker container that encapsulates the game 
# including user interface and sound.
# The container and game will run with the current host user for security reasons.

set -o errexit
set -o pipefail

# Limit number of CPU cores available to the container
N_CPUS=0

# Limit memory available to the container.
MEMORY=2g

# Get directory containing this script
THIS_DIR=$(cd $(dirname "${BASH_SOURCE[0]}"); pwd)

# Detect user and group info
USER_ID=$(id -u)
GROUP_ID=$(id -g)
USER_NAME=$(id -u -n)
GROUP_NAME=$(id -g -n)

XAUTH="${HOME}/.Xauthority"

# Check if the Docker image exists on the local host, if not build it.
if [[ "$(docker images -q java:microcraft10 2> /dev/null)" == "" ]]; then
  docker build --rm \
  -t java:microcraft10 \
  -f Dockerfile \
  --build-arg USER_ID="${USER_ID}" \
  --build-arg GROUP_ID="${GROUP_ID}" \
  --build-arg USER_NAME="${USER_NAME}" \
  --build-arg GROUP_NAME="${GROUP_NAME}" \
  "${THIS_DIR}"
fi

# Runs the container using the host's PulseAudio device and X Display.
# While the game is running in a container the sound and display is outputing on the host.
docker run --rm \
--name "microcraft" \
--cpuset-cpus "${N_CPUS}" \
--memory "${MEMORY}" \
--env DISPLAY="unix${DISPLAY}" \
--env PULSE_SERVER="unix:${XDG_RUNTIME_DIR}/pulse/native" \
--env XAUTHORITY="${XAUTH}" \
--volume "${XAUTH}:${XAUTH}" \
--volume "/tmp/.X11-unix:/tmp/.X11-unix" \
--volume "/var/run/dbus:/var/run/dbus" \
--volume "${XDG_RUNTIME_DIR}/pulse/native:${XDG_RUNTIME_DIR}/pulse/native" \
--volume "/dev/shm:/dev/shm" \
--volume "/dev/dri/card0:/dev/dri/card0" \
--device /dev/snd \
--device /dev/dri/card0 \
--user "${USER_ID}:${GROUP_ID}" \
java:microcraft10
